@@ -90,7 +90,7 @@ static void sort_real (SortDialog *dialog);
 static const GtkActionEntry action_entries[] =
 {
 	{ "Sort",
-	  GTK_STOCK_SORT_ASCENDING,
+	  "view-sort-ascending",
 	  N_("S_ort..."),
 	  NULL,
 	  N_("Sort the current document or selection"),
@@ -434,12 +434,10 @@ sort_real (SortDialog *dialog)
 					&start,
 					lines[i],
 					-1);
-
-		if (i < (num_lines - 1))
-			gtk_text_buffer_insert (GTK_TEXT_BUFFER (doc),
-						&start,
-						"\n",
-						-1);
+		gtk_text_buffer_insert (GTK_TEXT_BUFFER (doc),
+					&start,
+					"\n",
+					-1);
 
 		last_row = lines[i];
 	}
