@@ -142,7 +142,7 @@ set_logout_mode (PlumaCloseConfirmationDialog *dlg,
 
 		pluma_dialog_add_button (GTK_DIALOG (dlg),
 					 _("_Cancel Logout"),
-					 GTK_STOCK_CANCEL,
+					 "process-stop",
 					 GTK_RESPONSE_CANCEL);
 	}
 	else
@@ -151,8 +151,10 @@ set_logout_mode (PlumaCloseConfirmationDialog *dlg,
 				       _("Close _without Saving"),
 				       GTK_RESPONSE_NO);
 
-		gtk_dialog_add_button (GTK_DIALOG (dlg),
-				       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+		pluma_dialog_add_button (GTK_DIALOG (dlg),
+					 _("_Cancel"),
+					 "process-stop",
+					 GTK_RESPONSE_CANCEL);
 	}
 	
 	if (dlg->priv->disable_save_to_disk)
@@ -162,7 +164,7 @@ set_logout_mode (PlumaCloseConfirmationDialog *dlg,
 	}
 	else
 	{
-		const gchar *stock_id = GTK_STOCK_SAVE;
+		const gchar *icon_id = "document-save";
 		
 		if (GET_MODE (dlg->priv) == SINGLE_DOC_MODE)
 		{
@@ -172,12 +174,19 @@ set_logout_mode (PlumaCloseConfirmationDialog *dlg,
 			
 			if (pluma_document_get_readonly (doc) || 
 			    pluma_document_is_untitled (doc))
-				stock_id = GTK_STOCK_SAVE_AS;
+				icon_id = "document-save-as";
 		}
 
-		gtk_dialog_add_button (GTK_DIALOG (dlg),
-				       stock_id, 
-				       GTK_RESPONSE_YES);
+		if (g_strcmp0 (icon_id, "document-save") == 0)
+			pluma_dialog_add_button (GTK_DIALOG (dlg),
+						 _("_Save"),
+						 icon_id,
+						 GTK_RESPONSE_YES);
+		else
+			pluma_dialog_add_button (GTK_DIALOG (dlg),
+						 _("Save _As"),
+						 icon_id,
+						 GTK_RESPONSE_YES);
 
 		gtk_dialog_set_default_response	(GTK_DIALOG (dlg), 
 						 GTK_RESPONSE_YES);
@@ -767,11 +776,7 @@ build_multiple_docs_dialog (PlumaCloseConfirmationDialog *dlg)
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (select_label), treeview);
 
-	gtk_widget_show_all (hbox);
-
-	int new_width, new_height;
-	gtk_window_get_size (GTK_WINDOW (GTK_DIALOG (dlg)), &new_width, &new_height);
-	gtk_window_set_default_size (GTK_WINDOW (GTK_DIALOG (dlg)), new_width, new_height);
+	gtk_widget_show_all (hbox);	
 }
 
 static void
