@@ -90,16 +90,16 @@ set_contents (GtkWidget *area,
 }
 
 static void
-info_bar_add_stock_button_with_text (GtkInfoBar  *infobar,
-				     const gchar *text,
-				     const gchar *stock_id,
-				     gint         response_id)
+info_bar_add_icon_button_with_text (GtkInfoBar  *infobar,
+				    const gchar *text,
+				    const gchar *icon_id,
+				    gint         response_id)
 {
 	GtkWidget *button;
 	GtkWidget *image;
 
 	button = gtk_info_bar_add_button (infobar, text, response_id);
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+	image = gtk_image_new_from_icon_name (icon_id, GTK_ICON_SIZE_BUTTON);
 	gtk_button_set_image (GTK_BUTTON (button), image);
 }
 
@@ -162,9 +162,13 @@ create_io_loading_error_message_area (const gchar *primary_text,
 {
 	GtkWidget *message_area;
 
-	message_area = gtk_info_bar_new_with_buttons (
-					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					NULL);
+	message_area = gtk_info_bar_new ();
+
+	gtk_button_set_image (GTK_BUTTON (gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
+								   _("_Cancel"),
+								   GTK_RESPONSE_CANCEL)),
+			      gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_BUTTON));
+
 	gtk_info_bar_set_message_type (GTK_INFO_BAR (message_area),
 				       GTK_MESSAGE_ERROR);
 
@@ -175,10 +179,10 @@ create_io_loading_error_message_area (const gchar *primary_text,
 
 	if (recoverable_error)
 	{
-		info_bar_add_stock_button_with_text (GTK_INFO_BAR (message_area),
-						     _("_Retry"),
-						     GTK_STOCK_REFRESH,
-						     GTK_RESPONSE_OK);
+		info_bar_add_icon_button_with_text (GTK_INFO_BAR (message_area),
+						    _("_Retry"),
+						    "view-refresh",
+						    GTK_RESPONSE_OK);
 	}
 
 	return message_area;
@@ -477,10 +481,10 @@ create_conversion_error_message_area (const gchar *primary_text,
 
 	message_area = gtk_info_bar_new ();
 
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (message_area),
-					     _("_Retry"),
-					     GTK_STOCK_REDO,
-					     GTK_RESPONSE_OK);
+	info_bar_add_icon_button_with_text (GTK_INFO_BAR (message_area),
+					    _("_Retry"),
+					    "edit-redo",
+					    GTK_RESPONSE_OK);
 
 	if (edit_anyway)
 	{
@@ -499,9 +503,11 @@ create_conversion_error_message_area (const gchar *primary_text,
 	}
 	else
 	{
-		gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
-					 GTK_STOCK_CANCEL,
-					 GTK_RESPONSE_CANCEL);
+		gtk_button_set_image (GTK_BUTTON (gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
+									   _("_Cancel"),
+									   GTK_RESPONSE_CANCEL)),
+				      gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_BUTTON));
+
 		gtk_info_bar_set_message_type (GTK_INFO_BAR (message_area),
 					       GTK_MESSAGE_ERROR);
 	}
@@ -854,10 +860,10 @@ pluma_externally_modified_saving_error_message_area_new (
 
 	message_area = gtk_info_bar_new ();
 	
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (message_area),
-					     _("S_ave Anyway"),
-					     GTK_STOCK_SAVE,
-					     GTK_RESPONSE_YES);
+	info_bar_add_icon_button_with_text (GTK_INFO_BAR (message_area),
+					    _("S_ave Anyway"),
+					    "document-save",
+					    GTK_RESPONSE_YES);
 	gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
 				 _("D_on't Save"),
 				 GTK_RESPONSE_CANCEL);
@@ -950,10 +956,10 @@ pluma_no_backup_saving_error_message_area_new (const gchar  *uri,
 
 	message_area = gtk_info_bar_new ();
 	
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (message_area),
-					     _("S_ave Anyway"),
-					     GTK_STOCK_SAVE,
-					     GTK_RESPONSE_YES);
+	info_bar_add_icon_button_with_text (GTK_INFO_BAR (message_area),
+					    _("S_ave Anyway"),
+					    "document-save",
+					    GTK_RESPONSE_YES);
 	gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
 				 _("D_on't Save"),
 				 GTK_RESPONSE_CANCEL);
@@ -1175,13 +1181,16 @@ pluma_externally_modified_message_area_new (const gchar *uri,
 
 	message_area = gtk_info_bar_new ();
 	
-	info_bar_add_stock_button_with_text (GTK_INFO_BAR (message_area),
-					     _("_Reload"),
-					     GTK_STOCK_REFRESH,
-					     GTK_RESPONSE_OK);
-	gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
-				 GTK_STOCK_CANCEL,
-				 GTK_RESPONSE_CANCEL);
+	info_bar_add_icon_button_with_text (GTK_INFO_BAR (message_area),
+					    _("_Reload"),
+					    "view-refresh",
+					    GTK_RESPONSE_OK);
+
+	gtk_button_set_image (GTK_BUTTON (gtk_info_bar_add_button (GTK_INFO_BAR (message_area),
+								   _("_Cancel"),
+								   GTK_RESPONSE_CANCEL)),
+			      gtk_image_new_from_icon_name ("process-stop", GTK_ICON_SIZE_BUTTON));
+
 	gtk_info_bar_set_message_type (GTK_INFO_BAR (message_area),
 				       GTK_MESSAGE_WARNING);
 
