@@ -34,7 +34,7 @@
 #endif
 
 #include <glib/gi18n.h>
-#include <gtksourceview/gtksourceprintcompositor.h>
+#include <gtksourceview/gtksource.h>
 
 #include "pluma-print-job.h"
 #include "pluma-debug.h"
@@ -273,9 +273,8 @@ restore_button_clicked (GtkButton     *button,
 
 		font = pluma_prefs_manager_get_default_print_font_body ();
 
-		gtk_font_button_set_font_name (
-				GTK_FONT_BUTTON (job->priv->body_fontbutton),
-				font);
+		gtk_font_chooser_set_font (GTK_FONT_CHOOSER (job->priv->body_fontbutton),
+					   font);
 
 		g_free (font);
 	}
@@ -286,9 +285,8 @@ restore_button_clicked (GtkButton     *button,
 
 		font = pluma_prefs_manager_get_default_print_font_header ();
 
-		gtk_font_button_set_font_name (
-				GTK_FONT_BUTTON (job->priv->headers_fontbutton),
-				font);
+		gtk_font_chooser_set_font (GTK_FONT_CHOOSER (job->priv->headers_fontbutton),
+					   font);
 
 		g_free (font);
 	}
@@ -299,9 +297,8 @@ restore_button_clicked (GtkButton     *button,
 
 		font = pluma_prefs_manager_get_default_print_font_numbers ();
 
-		gtk_font_button_set_font_name (
-				GTK_FONT_BUTTON (job->priv->numbers_fontbutton),
-				font);
+		gtk_font_chooser_set_font (GTK_FONT_CHOOSER (job->priv->numbers_fontbutton),
+					   font);
 
 		g_free (font);
 	}
@@ -418,18 +415,18 @@ create_custom_widget_cb (GtkPrintOperation *operation,
 
 	/* Set initial values */
 	font = pluma_prefs_manager_get_print_font_body ();
-	gtk_font_button_set_font_name (GTK_FONT_BUTTON (job->priv->body_fontbutton),
-				       font);
+	gtk_font_chooser_set_font (GTK_FONT_CHOOSER (job->priv->body_fontbutton),
+				   font);
 	g_free (font);
 
 	font = pluma_prefs_manager_get_print_font_header ();
-	gtk_font_button_set_font_name (GTK_FONT_BUTTON (job->priv->headers_fontbutton),
-				       font);
+	gtk_font_chooser_set_font (GTK_FONT_CHOOSER (job->priv->headers_fontbutton),
+				   font);
 	g_free (font);
 
 	font = pluma_prefs_manager_get_print_font_numbers ();
-	gtk_font_button_set_font_name (GTK_FONT_BUTTON (job->priv->numbers_fontbutton),
-				       font);
+	gtk_font_chooser_set_font (GTK_FONT_CHOOSER (job->priv->numbers_fontbutton),
+				   font);
 	g_free (font);
 
 	can_set = pluma_prefs_manager_print_font_body_can_set ();
@@ -499,9 +496,9 @@ custom_widget_apply_cb (GtkPrintOperation *operation,
 		}	
 	}
 
-	pluma_prefs_manager_set_print_font_body (gtk_font_button_get_font_name (GTK_FONT_BUTTON (job->priv->body_fontbutton)));
-	pluma_prefs_manager_set_print_font_header (gtk_font_button_get_font_name (GTK_FONT_BUTTON (job->priv->headers_fontbutton)));
-	pluma_prefs_manager_set_print_font_numbers (gtk_font_button_get_font_name (GTK_FONT_BUTTON (job->priv->numbers_fontbutton)));
+	pluma_prefs_manager_set_print_font_body (gtk_font_chooser_get_font (GTK_FONT_CHOOSER (job->priv->body_fontbutton)));
+	pluma_prefs_manager_set_print_font_header (gtk_font_chooser_get_font (GTK_FONT_CHOOSER (job->priv->headers_fontbutton)));
+	pluma_prefs_manager_set_print_font_numbers (gtk_font_chooser_get_font (GTK_FONT_CHOOSER (job->priv->numbers_fontbutton)));
 }
 
 static void
@@ -517,11 +514,7 @@ create_compositor (PlumaPrintJob *job)
 	print_font_numbers = pluma_prefs_manager_get_print_font_numbers ();
 	
 	job->priv->compositor = GTK_SOURCE_PRINT_COMPOSITOR (
-#if GTK_CHECK_VERSION (3, 0, 0)
 					g_object_new (GTK_SOURCE_TYPE_PRINT_COMPOSITOR,
-#else
-					g_object_new (GTK_TYPE_SOURCE_PRINT_COMPOSITOR,
-#endif
 						     "buffer", GTK_SOURCE_BUFFER (job->priv->doc),
 						     "tab-width", gtk_source_view_get_tab_width (GTK_SOURCE_VIEW (job->priv->view)),
 						     "highlight-syntax", gtk_source_buffer_get_highlight_syntax (GTK_SOURCE_BUFFER (job->priv->doc)) &&
