@@ -680,7 +680,7 @@ show_loading_message_area (PlumaTab *tab)
 					       name_markup);
 		}
 		
-		area = pluma_progress_message_area_new (GTK_STOCK_REVERT_TO_SAVED,
+		area = pluma_progress_message_area_new ("document-revert",
 							msg,
 							TRUE);
 	}
@@ -703,7 +703,7 @@ show_loading_message_area (PlumaTab *tab)
 					       name_markup);
 		}
 
-		area = pluma_progress_message_area_new (GTK_STOCK_OPEN,
+		area = pluma_progress_message_area_new ("document-open",
 							msg,
 							TRUE);
 	}
@@ -792,7 +792,7 @@ show_saving_message_area (PlumaTab *tab)
 		msg = g_strdup_printf (_("Saving %s"), from_markup);
 	}
 
-	area = pluma_progress_message_area_new (GTK_STOCK_SAVE,
+	area = pluma_progress_message_area_new ("document-save",
 						msg,
 						FALSE);
 
@@ -889,7 +889,6 @@ document_loaded (PlumaDocument *document,
 	GtkWidget *emsg;
 	GFile *location;
 	gchar *uri;
-	const PlumaEncoding *encoding;
 
 	g_return_if_fail ((tab->priv->state == PLUMA_TAB_STATE_LOADING) ||
 			  (tab->priv->state == PLUMA_TAB_STATE_REVERTING));
@@ -916,8 +915,6 @@ document_loaded (PlumaDocument *document,
 		else
 			pluma_tab_set_state (tab, PLUMA_TAB_STATE_REVERTING_ERROR);
 
-		encoding = pluma_document_get_encoding (document);
-
 		if (error->domain == G_IO_ERROR &&
 		    error->code == G_IO_ERROR_CANCELLED)
 		{
@@ -1033,9 +1030,6 @@ document_loaded (PlumaDocument *document,
 			    	    g_file_equal (location, loc))
 			    	{
 			    		GtkWidget *w;
-			    		PlumaView *view;
-
-			    		view = pluma_tab_get_view (tab);
 
 			    		tab->priv->not_editable = TRUE;
 
@@ -2157,7 +2151,6 @@ _pluma_tab_save_as (PlumaTab                 *tab,
                     PlumaDocumentNewlineType  newline_type)
 {
 	PlumaDocument *doc;
-	PlumaDocumentSaveFlags save_flags;
 
 	g_return_if_fail (PLUMA_IS_TAB (tab));
 	g_return_if_fail ((tab->priv->state == PLUMA_TAB_STATE_NORMAL) ||
@@ -2182,11 +2175,6 @@ _pluma_tab_save_as (PlumaTab                 *tab,
 		 */
 
 		set_message_area (tab, NULL);
-		save_flags = tab->priv->save_flags | PLUMA_DOCUMENT_SAVE_IGNORE_MTIME;
-	}
-	else
-	{
-		save_flags = tab->priv->save_flags;
 	}
 
 	pluma_tab_set_state (tab, PLUMA_TAB_STATE_SAVING);
@@ -2500,11 +2488,11 @@ show_printing_message_area (PlumaTab *tab, gboolean preview)
 	GtkWidget *area;
 
 	if (preview)
-		area = pluma_progress_message_area_new (GTK_STOCK_PRINT_PREVIEW,
+		area = pluma_progress_message_area_new ("document-print-preview",
 							"",
 							TRUE);
 	else
-		area = pluma_progress_message_area_new (GTK_STOCK_PRINT,
+		area = pluma_progress_message_area_new ("document-print",
 							"",
 							TRUE);
 
@@ -2619,6 +2607,7 @@ _pluma_tab_can_close (PlumaTab *tab)
 {
 	PlumaDocument *doc;
 	PlumaTabState  ts;
+	GSettings *settings;
 
 	g_return_val_if_fail (PLUMA_IS_TAB (tab), FALSE);
 
@@ -2626,12 +2615,15 @@ _pluma_tab_can_close (PlumaTab *tab)
 
 	doc = pluma_tab_get_document (tab);
 
+	settings = g_settings_new ("org.mate.pluma");
+
 	/* if we are loading or reverting, the tab can be closed */
 	if ((ts == PLUMA_TAB_STATE_LOADING)         ||
 	    (ts == PLUMA_TAB_STATE_LOADING_ERROR)   ||
 	    (ts == PLUMA_TAB_STATE_REVERTING)       ||
 	    (ts == PLUMA_TAB_STATE_REVERTING_ERROR) || /* CHECK: I'm not sure this is the right behavior for REVERTING ERROR */
-	    (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc))))
+	    (!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc))) ||
+	    (!g_settings_get_boolean (settings, "show-save-confirmation")))
 		return TRUE;
 
 	/* Do not close tab with saving errors */
