@@ -107,8 +107,6 @@ static void	pluma_view_dispose		(GObject          *object);
 static void	pluma_view_finalize		(GObject          *object);
 static gint     pluma_view_focus_out		(GtkWidget        *widget,
 						 GdkEventFocus    *event);
-static gboolean pluma_view_scroll_event         (GtkWidget        *widget,
-                                                 GdkEventScroll   *event);
 static gboolean pluma_view_drag_motion		(GtkWidget        *widget,
 						 GdkDragContext   *context,
 						 gint              x,
@@ -183,36 +181,6 @@ document_read_only_notify_handler (PlumaDocument *document,
 				    !pluma_document_get_readonly (document));
 }
 
-static gboolean
-pluma_view_scroll_event (GtkWidget      *widget,
-                         GdkEventScroll *event)
-{
-	if (event->direction == GDK_SCROLL_UP)
-	{
-		event->delta_x = 0;
-		event->delta_y = -1;
-	}
-	else if (event->direction == GDK_SCROLL_DOWN)
-	{
-		event->delta_x = 0;
-		event->delta_y = 1;
-	}
-	else if (event->direction == GDK_SCROLL_LEFT)
-	{
-		event->delta_x = -1;
-		event->delta_y = 0;
-	}
-	else if (event->direction == GDK_SCROLL_RIGHT)
-	{
-		event->delta_x = 1;
-		event->delta_y = 0;
-	}
-
-	event->direction = GDK_SCROLL_SMOOTH;
-
-	return FALSE;
-}
-
 static void
 pluma_view_class_init (PlumaViewClass *klass)
 {
@@ -227,7 +195,6 @@ pluma_view_class_init (PlumaViewClass *klass)
 
 	widget_class->focus_out_event = pluma_view_focus_out;
 	widget_class->draw = pluma_view_draw;
-	widget_class->scroll_event = pluma_view_scroll_event;
 	
 	/*
 	 * Override the gtk_text_view_drag_motion and drag_drop
@@ -679,6 +646,35 @@ pluma_view_scroll_to_cursor (PlumaView *view)
 				      0.0);
 }
 
+static void
+pluma_override_font (GtkWidget   *widget,
+		     const gchar *font)
+{
+	gchar          *css;
+	GtkCssProvider *provider;
+	gchar          *tempsize;
+
+	provider = gtk_css_provider_new ();
+	tempsize = g_strdup (font);
+
+	g_strreverse (tempsize);
+	g_strcanon (tempsize, "1234567890", '\0');
+	g_strreverse (tempsize);
+
+	gchar tempfont [strlen (font)];
+	strcpy (tempfont, font);
+	tempfont [strlen (font) - strlen (tempsize)] = 0;
+
+	css = g_strdup_printf ("textview { font-family: %s; font-size: %spt; }", tempfont, tempsize);
+	gtk_css_provider_load_from_data (provider, css, -1, NULL);
+	g_free (css);
+
+	gtk_style_context_add_provider (gtk_widget_get_style_context (widget),
+					GTK_STYLE_PROVIDER (provider),
+					GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	g_object_unref (provider);
+}
+
 /* FIXME this is an issue for introspection */
 /**
  * pluma_view_set_font:
@@ -717,7 +713,7 @@ pluma_view_set_font (PlumaView   *view,
 
 	g_return_if_fail (font_desc != NULL);
 
-	gtk_widget_override_font (GTK_WIDGET (view), font_desc);
+	pluma_override_font (GTK_WIDGET (view), pango_font_description_to_string (font_desc));
 
 	pango_font_description_free (font_desc);		
 }
@@ -2018,13 +2014,7 @@ show_line_numbers_menu (GtkWidget      *view,
 
 	menu = create_line_numbers_menu (view);
 
-	gtk_menu_popup (GTK_MENU (menu), 
-			NULL, 
-			NULL,
-			NULL, 
-			NULL,
-			event->button, 
-			event->time);
+	gtk_menu_popup_at_pointer (GTK_MENU (menu), NULL);
 }
 
 static gboolean
